<?php
/*
Plugin Name: Syria Refugee Slider
Plugin URI: http://www.trenzasoft.com
Description: A simple plugin that integrates FlexSlider (http://flex.madebymufffin.com/) with WordPress using custom post types!. It's for a charity cause to raise awareness about how many refugees still need our help. Use this shortcode [srs_slider];
Author: Trenza Softwares
Version: 1.0
Author URI: http://www.trenzasoft.com
*/

define('SRS_PATH', WP_PLUGIN_URL . '/' . plugin_basename( dirname(__FILE__) ) . '/' );
define('SRS_NAME', "Syria Refugee Slider");
define ("SRS_VERSION", "1.0");

define('CPT_NAME', "Syria Slider");
define('CPT_SINGLE', "Syria Slider");
define('CPT_TYPE', "syria-slider");

add_action('wp_head', 'srs_script');
add_action('init', 'srs_register_slider');
add_action('add_meta_boxes', 'add_srs_meta_box');
add_action('save_post', 'save_srs_meta');

add_shortcode('srs_slider', 'srs_insert_slider');

function srs_script(){
    wp_enqueue_script('flexslider', SRS_PATH.'js/jquery.flexslider-min.js', array('jquery'));
    wp_enqueue_script('flexslider_callback', SRS_PATH.'js/jquery.srs.callback.js', array('jquery'));
    wp_enqueue_style('flexslider_css', SRS_PATH.'css/flexslider.css');
}

function srs_register_slider() {  
    $args = array(  
        'label' => __(CPT_NAME),  
        'singular_label' => __(CPT_SINGLE),  
        'public' => false,  
        'show_ui' => true,  
        'capability_type' => 'post',  
        'hierarchical' => false,  
        'rewrite' => true,  
        'menu_position' => 80,
        'supports' => array('title', 'thumbnail')  
       );  
    register_post_type(CPT_TYPE , $args ); 
    add_theme_support('post-thumbnails', array('syria-slider'));
    add_filter('widget_text', 'do_shortcode');
}


// Add the Meta Box
function add_srs_meta_box() {
    add_meta_box(
        'srs_meta_box', // $id
        'Syria Refugee Meta Box', // $title 
        'show_srs_meta_box', // $callback
        CPT_TYPE, // $page
        'normal', // $context
        'high'); // $priority
}

$prefix = CPT_TYPE;
$srs_meta_fields = array(
    array(
        'label'=> 'Slider Caption',
        'desc'  => 'Type Your Slider Caption Here',
        'id'    => $prefix.'caption',
        'type'  => 'textarea'
    ),
    array(
        'label'=> 'Slider Link',
        'desc'  => 'Type Your Slider Link Here<br /> Ex: http://hulpvoorsyrie.nl/doneer/',
        'id'    => $prefix.'link',
        'type'  => 'text'
    ),
);

// The Callback
function show_srs_meta_box() {
    global $srs_meta_fields, $post;
    // Use nonce for verification
    echo '<input type="hidden" name="srs_meta_box_nonce" value="'.wp_create_nonce(basename(__FILE__)).'" />';
         
        // Begin the field table and loop
        echo '<table class="form-table">';
        foreach ($srs_meta_fields as $field) {
            // get value of this field if it exists for this post
            $meta = get_post_meta($post->ID, $field['id'], true);
            // begin a table row with
            echo '<tr>
                    <th><label for="'.$field['id'].'">'.$field['label'].'</label></th>
                    <td>';
                    switch($field['type']) {
                        // text
                        case 'text':
                            echo '<input type="text" name="'.$field['id'].'" id="'.$field['id'].'" value="'.$meta.'" size="30" />
                                <br /><span class="description">'.$field['desc'].'</span>';
                        break;
                        
                        // textarea
                        case 'textarea':
                            echo '<textarea name="'.$field['id'].'" id="'.$field['id'].'" cols="60" rows="4">'.$meta.'</textarea>
                                <br /><span class="description">'.$field['desc'].'</span>';
                        break;
                    } //end switch
            echo '</td></tr>';
        } // end foreach
        echo '</table>'; // end table
}

// Save the Data
function save_srs_meta($post_id) {
    global $srs_meta_fields;
     
    // verify nonce
    if (!wp_verify_nonce($_POST['srs_meta_box_nonce'], basename(__FILE__))) 
        return $post_id;
    // check autosave
    if (defined('DOING_AUTOSAVE') && DOING_AUTOSAVE)
        return $post_id;
    // check permissions
    if ('page' == $_POST['post_type']) {
        if (!current_user_can('edit_page', $post_id))
            return $post_id;
        } elseif (!current_user_can('edit_post', $post_id)) {
            return $post_id;
    }
     
    // loop through fields and save the data
    foreach ($srs_meta_fields as $field) {
        $old = get_post_meta($post_id, $field['id'], true);
        $new = $_POST[$field['id']];
        if ($new && $new != $old) {
            update_post_meta($post_id, $field['id'], $new);
        } elseif ('' == $new && $old) {
            delete_post_meta($post_id, $field['id'], $old);
        }
    } // end foreach
}


function srs_insert_slider(){
    global $post;
    
    $args = array(
    	'posts_per_page'   => -1,
    	'post_type'        => CPT_TYPE,
        'order'            => 'ASC',
    );
    
    $posts_array = get_posts( $args );
        
    if(isset($posts_array)){
        $slider= '<div class="srs_flexslider"><ul class="slides">';
        foreach ( $posts_array as $post ) : setup_postdata( $post );

            $link = get_post_meta($post->ID,'syria-sliderlink',true);
            $caption = get_post_meta($post->ID,'syria-slidercaption',true);
            $slider.='<li><div class="slider_smr">';
            if($link){$slider.='<a target="_blank" href="'.$link.'">'; }
            $img= get_the_post_thumbnail( $post->ID, 'large' );
            $slider.= $img;
            if($caption){$slider.= '<div class="srs_caption"><div>'.$caption.'</div></div>';}
            if($link){$slider.='</a>'; }
            $slider.='</div></li>';		
    			
        endforeach; 
        wp_reset_postdata();
    	$slider.= '</ul></div>';
	}
	return $slider;
}
